@@ -4,6 +4,16 @@ from mw_python_sdk import download_file
 
 
 class TestDownloadFile(unittest.TestCase):
+    def test_download_specific_version(self):
+        dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
+        try:  # Example assertion
+            download_file(
+                dataset_id_tmp,
+                "b_local_dir/heart_2020_cleaned.csv",
+                commit="66b472ea7a15d14beb825911",
+            )
+        except Exception as err:
+            print(f"An error occurred: {err}")
     def test_download(self):
         dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
         try:  # Example assertion
